@@ -1,4 +1,4 @@
-#' @title Checks if a regression model object is supported in \pkg{insight} package
+#' @title Checks if a regression model object is supported by the insight package
 #' @name is_model_supported
 #'
 #' @description Small helper that checks if a model is a *supported*
@@ -106,8 +106,8 @@ supported_models <- function() {
     "robtab", "RM", "rma", "rma.uni", "robmixglm", "rq", "rqs", "rqss", "rvar",
 
     # s ----------------------------
-    "Sarlm", "scam", "selection", "sem", "semLm", "semLme", "SemiParBIV", "slm",
-    "speedlm", "speedglm", "stanfit", "stanmvreg", "stanreg", "summary.lm",
+    "Sarlm", "scam", "selection", "sem", "semLm", "semLme", "SemiParBIV", "serp",
+    "slm", "speedlm", "speedglm", "stanfit", "stanmvreg", "stanreg", "summary.lm",
     "survfit", "survreg", "svy_vglm", "svychisq", "svyglm", "svyolr",
 
     # t ----------------------------
