@@ -9,6 +9,13 @@
 #' compact_list(c(1, NA, NA), remove_na = TRUE)
 #' @export
 compact_list <- function(x, remove_na = FALSE) {
+  # remove vctr-class attributes
+  if (is.data.frame(x)) {
+    x[] <- lapply(x, function(i) {
+      class(i) <- setdiff(class(i), c("haven_labelled", "vctrs_vctr"))
+      i
+    })
+  }
   if (remove_na) {
     x[!sapply(x, function(i) !is_model(i) && !inherits(i, c("Formula", "gFormula")) && (length(i) == 0L || is.null(i) || (length(i) == 1L && is.na(i)) || all(is.na(i)) || any(i == "NULL", na.rm = TRUE)))]
   } else {
@@ -30,5 +37,5 @@ compact_list <- function(x, remove_na = FALSE) {
 #'
 #' @export
 compact_character <- function(x) {
-  x[!sapply(x, function(i) nchar(i) == 0 || all(is.na(i)) || any(i == "NULL", na.rm = TRUE))]
+  x[!sapply(x, function(i) !nzchar(i, keepNA = TRUE) || all(is.na(i)) || any(i == "NULL", na.rm = TRUE))]
 }
