@@ -2,6 +2,7 @@ skip_on_cran()
 skip_if_offline()
 skip_on_os("mac")
 skip_if_not_installed("brms")
+skip_if_not_installed("httr")
 
 # Model fitting -----------------------------------------------------------
 
@@ -352,7 +353,7 @@ test_that("find_paramaters", {
           sigma = "sigma_SepalWidth"
         )
       ),
-      "is_mv" = "1"
+      is_mv = "1"
     )
   )
 
@@ -390,7 +391,7 @@ test_that("find_paramaters", {
           )
         )
       ),
-      "is_mv" = "1"
+      is_mv = "1"
     )
   )
 })
