@@ -16,7 +16,7 @@ test_that("get_datagrid - data from models", {
 test_that("get_datagrid - preserve factor levels #695", {
   dat <<- transform(mtcars, cyl = factor(cyl))
   mod <- lm(mpg ~ cyl + am + hp, data = dat)
-  grid <- get_datagrid(mod, at = "hp")
+  grid <- get_datagrid(mod, by = "hp")
   expect_identical(levels(grid$cyl), c("4", "6", "8"))
 })
 
@@ -84,10 +84,10 @@ test_that("get_datagrid - column order", {
 
 # list-argument
 test_that("get_datagrid - list-argument", {
-  at <- list(Sepal.Length = c(3, 5), Species = c("versicolor", "virginica"))
-  dg1 <- get_datagrid(iris, at = at)
-  at <- c("Sepal.Length = c(3, 5)", "Species = c('versicolor', 'virginica')")
-  dg2 <- get_datagrid(iris, at = at)
+  by <- list(Sepal.Length = c(3, 5), Species = c("versicolor", "virginica"))
+  dg1 <- get_datagrid(iris, by = by)
+  by <- c("Sepal.Length = c(3, 5)", "Species = c('versicolor', 'virginica')")
+  dg2 <- get_datagrid(iris, by = by)
 
   expect_equal(dg1, dg2, tolerance = 1e-4)
 })
@@ -99,11 +99,11 @@ test_that("get_datagrid - data", {
   # Factors
   expect_length(get_datagrid(iris$Species), 3)
   expect_length(get_datagrid(c("A", "A", "B")), 2)
-  expect_length(get_datagrid(x = iris$Species, at = "c('versicolor')"), 1)
-  expect_length(get_datagrid(iris$Species, at = "A = c('versicolor')"), 1)
-  expect_length(get_datagrid(c("A", "A", "B"), at = "dupa = 'A'"), 1)
-  expect_length(get_datagrid(iris$Species, at = "['versicolor', 'virginica']"), 2)
-  expect_length(get_datagrid(iris$Species, at = "[versicolor, virginica]"), 2)
+  expect_length(get_datagrid(x = iris$Species, by = "c('versicolor')"), 1)
+  expect_length(get_datagrid(iris$Species, by = "A = c('versicolor')"), 1)
+  expect_length(get_datagrid(c("A", "A", "B"), by = "dupa = 'A'"), 1)
+  expect_length(get_datagrid(iris$Species, by = "['versicolor', 'virginica']"), 2)
+  expect_length(get_datagrid(iris$Species, by = "[versicolor, virginica]"), 2)
 
   # Numerics
   expect_length(get_datagrid(x = iris$Sepal.Length), 10)
@@ -112,36 +112,36 @@ test_that("get_datagrid - data", {
   expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "iqr")), as.numeric(quantile(iris$Sepal.Length, 0.025))) # nolint
   expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "hdi")), as.numeric(bayestestR::hdi(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
   expect_identical(min(get_datagrid(x = iris$Sepal.Length, range = "eti")), as.numeric(bayestestR::eti(iris$Sepal.Length, ci = 0.95, verbose = FALSE))[2]) # nolint
-  expect_length(get_datagrid(iris$Sepal.Length, at = "c(1, 3, 4)"), 3)
-  expect_length(get_datagrid(iris$Sepal.Length, at = "A = c(1, 3, 4)"), 3)
-  expect_length(get_datagrid(iris$Sepal.Length, at = "[1, 3, 4]"), 3)
-  expect_length(get_datagrid(iris$Sepal.Length, at = "[1, 4]"), 10)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "c(1, 3, 4)"), 3)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "A = c(1, 3, 4)"), 3)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "[1, 3, 4]"), 3)
+  expect_length(get_datagrid(iris$Sepal.Length, by = "[1, 4]"), 10)
   expect_length(get_datagrid(iris$Sepal.Length, range = "sd", length = 10), 10)
   expect_identical(as.numeric(get_datagrid(iris$Sepal.Length, range = "sd", length = 3)[2]), mean(iris$Sepal.Length))
   expect_identical(as.numeric(get_datagrid(iris$Sepal.Length, range = "mad", length = 4)[2]), median(iris$Sepal.Length))
 
   # Dataframes
   expect_identical(nrow(get_datagrid(iris, length = 2)), 48L)
-  expect_identical(nrow(get_datagrid(iris, at = "Species", length = 2, numerics = 0)), 3L)
-  expect_identical(nrow(get_datagrid(iris, at = "Sepal.Length", length = 3)), 3L)
-  expect_identical(dim(get_datagrid(iris, at = 1:2, length = 3)), c(9L, 5L))
-  expect_identical(dim(get_datagrid(iris, at = 1:2, length = c(3, 2))), c(6L, 5L))
-  expect_identical(dim(get_datagrid(iris, at = 1:2, length = c(NA, 2))), c(70L, 5L))
-  expect_identical(dim(get_datagrid(iris, at = "Sepal.Length = c(1, 2)", length = NA)), c(2L, 5L))
-  expect_error(get_datagrid(iris, at = 1:2, length = c(3, 2, 4)))
-  expect_error(get_datagrid(iris, at = 1:2, length = "yes"))
-  expect_identical(as.numeric(get_datagrid(iris, at = 1:2, range = c("range", "mad"), length = c(2, 3))[4, "Sepal.Width"]), median(iris$Sepal.Width)) # nolint
+  expect_identical(nrow(get_datagrid(iris, by = "Species", length = 2, numerics = 0)), 3L)
+  expect_identical(nrow(get_datagrid(iris, by = "Sepal.Length", length = 3)), 3L)
+  expect_identical(dim(get_datagrid(iris, by = 1:2, length = 3)), c(9L, 5L))
+  expect_identical(dim(get_datagrid(iris, by = 1:2, length = c(3, 2))), c(6L, 5L))
+  expect_identical(dim(get_datagrid(iris, by = 1:2, length = c(NA, 2))), c(70L, 5L))
+  expect_identical(dim(get_datagrid(iris, by = "Sepal.Length = c(1, 2)", length = NA)), c(2L, 5L))
+  expect_error(get_datagrid(iris, by = 1:2, length = c(3, 2, 4)))
+  expect_error(get_datagrid(iris, by = 1:2, length = "yes"))
+  expect_identical(as.numeric(get_datagrid(iris, by = 1:2, range = c("range", "mad"), length = c(2, 3))[4, "Sepal.Width"]), median(iris$Sepal.Width)) # nolint
 
   expect_identical(nrow(get_datagrid(data.frame(
     X = c("A", "A", "B"),
     Y = c(1, 5, 2),
     stringsAsFactors = FALSE
-  ), at = "Y", factors = "mode", length = 5)), 5L)
+  ), by = "Y", factors = "mode", length = 5)), 5L)
 
-  expect_identical(nrow(get_datagrid(iris, at = c("Sepal.Length = 3", "Species"))), 3L)
-  expect_identical(nrow(get_datagrid(iris, at = c("Sepal.Length = c(3, 1)", "Species = 'setosa'"))), 2L)
+  expect_identical(nrow(get_datagrid(iris, by = c("Sepal.Length = 3", "Species"))), 3L)
+  expect_identical(nrow(get_datagrid(iris, by = c("Sepal.Length = c(3, 1)", "Species = 'setosa'"))), 2L)
 
-  x1 <- get_datagrid(iris, at = c("Species", "Sepal.Length"), length = 30, preserve_range = TRUE)
+  x1 <- get_datagrid(iris, by = c("Species", "Sepal.Length"), length = 30, preserve_range = TRUE)
   expect_identical(dim(x1), c(55L, 5L))
   x2 <- get_datagrid(iris[c("Species", "Sepal.Length")], length = 30, preserve_range = TRUE)
   expect_identical(dim(x2), c(55L, 2L))
@@ -268,14 +268,14 @@ test_that("factor levels as reference / non-focal terms works", {
   expect_warning(
     insight::get_datagrid(
       model,
-      at = "k618", range = "grid", preserve_range = FALSE,
+      by = "k618", range = "grid", preserve_range = FALSE,
       verbose = TRUE, include_response = FALSE
     )
   )
 
   grid <- insight::get_datagrid(
     model,
-    at = "k618", range = "grid", preserve_range = FALSE,
+    by = "k618", range = "grid", preserve_range = FALSE,
     verbose = FALSE, include_response = TRUE
   )
   expect_identical(
